@@ -4,6 +4,8 @@ import requests
 import urllib
 from cloudutils.vault import Vault
 
+log = logging.getLogger(__name__)
+
 
 class VaultGCE(Vault):
 
@@ -32,5 +34,5 @@ class VaultGCE(Vault):
 
             return {"role": role, "jwt": jwt}
         except Exception as e:
-            print('Failed to generate auth payload! %s: %s' % (type(e).__name__, e))
+            log.error('Failed to generate auth payload! %s: %s' % (type(e).__name__, e))
             raise
